==> jc-1.4.0.tar.gz: gnu/regexp/CharIndexedStringBuffer.h <==
// class gnu.regexp.CharIndexedStringBuffer

// class file dependencies
// @dep_class 7664afbfb6be49e7 gnu_regexp_CharIndexedStringBuffer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedStringBuffer_H_
#define _JC_gnu_regexp_CharIndexedStringBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs	_jc_gnu_regexp_CharIndexedStringBuffer$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs	_jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$refs	_jc_gnu_regexp_CharIndexedStringBuffer$refs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$nonrefs	_jc_gnu_regexp_CharIndexedStringBuffer$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$object	_jc_gnu_regexp_CharIndexedStringBuffer$object;

typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vmethods	_jc_gnu_regexp_CharIndexedStringBuffer$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vtable	_jc_gnu_regexp_CharIndexedStringBuffer$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vtype	_jc_gnu_regexp_CharIndexedStringBuffer$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedStringBuffer$method$_init$1a25222faf8d9717(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, struct _jc_java_lang_StringBuffer$object *, jint);

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedStringBuffer$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint);
extern jboolean _jc_gnu_regexp_CharIndexedStringBuffer$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *);
extern jboolean _jc_gnu_regexp_CharIndexedStringBuffer$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedStringBuffer$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *);
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint);
};

// Vtable
struct _jc_gnu_regexp_CharIndexedStringBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedStringBuffer$vmethods	gnu_regexp_CharIndexedStringBuffer;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedStringBuffer$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedStringBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedStringBuffer$refs {
    _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs	gnu_regexp_CharIndexedStringBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs {
	jint	anchor;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedStringBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs	gnu_regexp_CharIndexedStringBuffer;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedStringBuffer$object {
	_jc_gnu_regexp_CharIndexedStringBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedStringBuffer$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedStringBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedStringBuffer$vtype _jc_gnu_regexp_CharIndexedStringBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedStringBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedStringBuffer$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedStringBuffer_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/CharIndexedStringBuffer.h <==
// class gnu.regexp.CharIndexedStringBuffer

// class file dependencies
// @dep_class 7664afbfb6be49e7 gnu_regexp_CharIndexedStringBuffer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedStringBuffer_H_
#define _JC_gnu_regexp_CharIndexedStringBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs	_jc_gnu_regexp_CharIndexedStringBuffer$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs	_jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$refs	_jc_gnu_regexp_CharIndexedStringBuffer$refs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$nonrefs	_jc_gnu_regexp_CharIndexedStringBuffer$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedStringBuffer$object	_jc_gnu_regexp_CharIndexedStringBuffer$object;

typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vmethods	_jc_gnu_regexp_CharIndexedStringBuffer$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vtable	_jc_gnu_regexp_CharIndexedStringBuffer$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedStringBuffer$vtype	_jc_gnu_regexp_CharIndexedStringBuffer$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedStringBuffer$method$_init$1a25222faf8d9717(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, struct _jc_java_lang_StringBuffer$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedStringBuffer$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedStringBuffer$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedStringBuffer$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedStringBuffer$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedStringBuffer$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedStringBuffer$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_CharIndexedStringBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedStringBuffer$vmethods	gnu_regexp_CharIndexedStringBuffer;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedStringBuffer$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedStringBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedStringBuffer$refs {
    _jc_gnu_regexp_CharIndexedStringBuffer$sub_refs	gnu_regexp_CharIndexedStringBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs {
	jint	anchor;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedStringBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedStringBuffer$sub_nonrefs	gnu_regexp_CharIndexedStringBuffer;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedStringBuffer$object {
	_jc_gnu_regexp_CharIndexedStringBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedStringBuffer$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedStringBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedStringBuffer$vtype _jc_gnu_regexp_CharIndexedStringBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedStringBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedStringBuffer$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedStringBuffer_H_ */
